@@ -4,6 +4,7 @@ License: GPLv2, read more from COPYING
 Track is always in pipeline. Track contains samples.
 */
 #include "track.h"
+#include "../../chum/chum.h" //because of DATA_DIR
 
 //private functions
 static void trackbin_and_link(Track *trc,GstElement *audioconvertA,GstElement *audioconvertB);
@@ -233,8 +234,7 @@ void create_new_singing_track(void)
 //return trc;
 }
 
-
-#define INSTRUMENT_FOLDER "../share/jammo/virtual-instruments/"
+#define INSTRUMENT_FOLDER g_strdup_printf("%s/virtual-instruments/",DATA_DIR)
 /**
  *  create_new_empty_track - for virtual instruments. 
 parameter in this moment:
